pub struct Project {
pub modules: Vec<Module>,
pub reflection: CodebaseReflection,
}Expand description
Represents a complete PHP code project.
A Project is composed of multiple modules along with a unified reflection of the codebase.
The reflection provides a merged view of code insights (such as classes and functions) extracted from each module.
Fields
modules: Vec<Module>A list of modules that comprise the project.
reflection: CodebaseReflectionThe merged reflection of the project containing information aggregated from each module.
Implementations
Sourceimpl Project
impl Project
Sourcepub fn builder(interner: ThreadedInterner) -> ProjectBuilder
pub fn builder(interner: ThreadedInterner) -> ProjectBuilder
Creates a new ProjectBuilder to start building a project.